@@ -171,8 +171,8 @@ class CreateMo(object):
         self.host = '172.31.216.100' if os.uname()[1] == 'BONHUAN-M-D891' else None
         self.user = 'admin' if os.uname()[1] == 'BONHUAN-M-D891' else None
         self.password = 'ins3965!' if os.uname()[1] == 'BONHUAN-M-D891' else None
-        self.tenant = self.tenant if hasattr(self, 'tenant') and os.uname()[1] == 'BONHUAN-M-D891' else 'bon'  # for testing myself
-        # self.tenant = self.tenant if hasattr(self, 'tenant') else 'None'    # the proper way
+        # self.tenant = self.tenant if hasattr(self, 'tenant') and os.uname()[1] == 'BONHUAN-M-D891' else 'bon'  # for testing myself
+        self.tenant = self.tenant if hasattr(self, 'tenant') else 'None'    # the proper way
         self.application = None
         self.modir = None
         self.mo = None
